@@ -655,6 +655,7 @@ sub parseFilter
 
             my $assval =  decode('utf8', $args->{assertionValue});
             if ($op eq 'equalityMatch') {
+                $assval =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                 $rc = ($val =~ /^$assval$/i);
             } elsif ($op eq 'greaterOrEqual') {
                 $rc = ($val ge $assval);
@@ -670,13 +671,16 @@ sub parseFilter
     } elsif ($op eq 'substrings') {
         if (defined($args->{substrings}[0]{initial})) {
             my $substr = decode('utf8', $args->{substrings}[0]{initial});
-            return $entry =~ /^$args->{type}: $substr.*$/mi;
+            $substr =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
+            return $entry =~ /^$args->{type};?.*: $substr.*$/mi;
         } elsif (defined($args->{substrings}[0]{final})) {
             my $substr = decode('utf8', $args->{substrings}[0]{final});
-            return $entry =~ /^$args->{type}: .*$substr$/mi;
+            $substr =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
+            return $entry =~ /^$args->{type};?.*: .*$substr$/mi;
         } else {
             my $substr = decode('utf8', $args->{substrings}[0]{any});
-            return $entry =~ /^$args->{type}: .*$substr.*$/mi;
+            $substr =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
+            return $entry =~ /^$args->{type};?.*: .*$substr.*$/mi;
         }
     } elsif ($op eq 'present') {
         return $entry =~ /^$args: /mi;
@@ -1107,6 +1111,7 @@ sub _baseSearch
     }
 
     my ($rdn, $pdn) = ($base =~ /^([^,]+),(.*)$/);
+    $rdn =~ s/([&|!*\(\)])/\\$1/g;
     my $filterStr = "(".encode('utf8', $rdn).")";
     if ($filter) {
         $filterStr = "(&".$filterStr.$filter->as_string.")";
