@@ -488,7 +488,7 @@ sub _do_search
     # Attribute mapping
     foreach my $ldapmap (@{$conf->{ldapmap}}) {
         if ($ldapmap->{type} =~ /^objectclass$/i) {
-            $filterStr =~ s/objectClass=$ldapmap->{local}$/objectClass=$ldapmap->{foreign}/mi;
+            $filterStr =~ s/objectClass=$ldapmap->{local}/objectClass=$ldapmap->{foreign}/mi;
         } else {
             $filterStr =~ s/\($ldapmap->{local}=/\($ldapmap->{foreign}=/mi;
         }
